/*
 * mdh (MailDooHicky), a GTK+-based toolbar.
 *
 * Copyright (c) 2003-2005 by Mike Hokenson <mdh at gozer dot org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef HAVE_GLIBTOP_H

#include <glibtop.h>
#include <glibtop/open.h>
#include <glibtop/close.h>

#include <glibtop/loadavg.h>
#include <glibtop/cpu.h>
#include <glibtop/mem.h>
#include <glibtop/swap.h>
#include <glibtop/fsusage.h>
#include <glibtop/netload.h>
#include <glibtop/uptime.h>

static gboolean init = FALSE;

static gint gtop_ncpu = 1;

gboolean mdh_gtop_init(void)
{
    if(init)
        return(TRUE);

    glibtop_init();

    if(glibtop_global_server && glibtop_global_server->ncpu)
        gtop_ncpu = glibtop_global_server->ncpu;

    init = TRUE;

    return(TRUE);
}

void mdh_gtop_close(void)
{
    if(!init)
        return;

    init = FALSE;

    glibtop_close();
}

void mdh_gtop_get_cpu(gdouble loadavg[3],
                      guint64 *nr_running,
                      guint64 *nr_tasks,
                      guint   *ncpu,
                      gdouble *total,
                      gdouble *user,
                      gdouble *nice,
                      gdouble *sys,
                      gdouble *idle)
{
    glibtop_loadavg glt_a;
    glibtop_cpu glt_r;

    glibtop_get_loadavg(&glt_a);

    if(loadavg) {
        loadavg[0] = glt_a.loadavg[0];
        loadavg[1] = glt_a.loadavg[1];
        loadavg[2] = glt_a.loadavg[2];
    }

    if(nr_running)
        *nr_running = glt_a.nr_running;

    if(nr_tasks)
        *nr_tasks   = glt_a.nr_tasks;

    if(ncpu)
        *ncpu = gtop_ncpu;

    glibtop_get_cpu(&glt_r);

    if(total)
        *total = ((glt_r.total) ? (gdouble) glt_r.total : 1.0) / gtop_ncpu;

    if(user)
        *user  = ((glt_r.user)  ? (gdouble) glt_r.user  : 1.0) / gtop_ncpu;

    if(nice)
        *nice  = ((glt_r.nice)  ? (gdouble) glt_r.nice  : 1.0) / gtop_ncpu;

    if(sys)
        *sys   = ((glt_r.sys)   ? (gdouble) glt_r.sys   : 1.0) / gtop_ncpu;

    if(idle)
        *idle  = ((glt_r.idle)  ? (gdouble) glt_r.idle  : 1.0) / gtop_ncpu;
}

void mdh_gtop_get_mem(guint64 *total,
                      guint64 *used,
                      guint64 *free,
                      guint64 *buff)
{
    glibtop_mem  glt;

    glibtop_get_mem(&glt);

    if(total)
        *total = glt.total;

    if(used)
        *used  = glt.used;

    if(free)
        *free  = glt.free;

    if(buff)
        *buff  = glt.cached + glt.buffer;
}

void mdh_gtop_get_swap(guint64 *total, guint64 *used, guint64 *free)
{
    glibtop_swap glt;

    glibtop_get_swap(&glt);

    if(total)
        *total = glt.total;

    if(used)
        *used  = glt.used;

    if(free)
        *free  = glt.free;
}

void mdh_gtop_get_disk(const gchar *fs,
                       guint64 *total,
                       guint64 *free,
                       guint64 *avail)
{
    glibtop_fsusage glt;

    g_return_if_fail(fs != NULL);

    glibtop_get_fsusage(&glt, fs);

    if(total)
        *total = glt.blocks * glt.block_size;

    if(free)
        *free  = glt.bfree  * glt.block_size;

    if(avail)
        *avail = glt.bavail * glt.block_size;
}

void mdh_gtop_get_net(const gchar *dev, guint64 *rx, guint64 *tx, gboolean *up)
{
    guint64  net_rx = 0, net_tx = 0;
    gboolean net_up = FALSE;

    glibtop_netload glt;

    g_return_if_fail(dev != NULL);

    glibtop_get_netload(&glt, dev);

    if(glt.if_flags & (1 << GLIBTOP_IF_FLAGS_UP)) {
        net_rx = glt.bytes_in;
        net_tx = glt.bytes_out;
        net_up = TRUE;
    }

    if(rx)
        *rx = net_rx;

    if(tx)
        *tx = net_tx;

    if(up)
        *up = net_up;
}

void mdh_gtop_get_uptime(gulong *seconds)
{
    glibtop_uptime glt;

    glibtop_get_uptime(&glt);

    if(seconds)
        *seconds = glt.uptime;
}

#endif /* HAVE_GLIBTOP_H */
